#!/usr/bin/env python
#
# pynssp documentation build configuration file, created by
# sphinx-quickstart on Fri Jun  9 13:47:02 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it
# absolute, like shown here.
#
import os
import sys
from os.path import basename, dirname, realpath
sys.path.insert(0, os.path.abspath('..'))
import pynssp

# -- General configuration ---------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    'sphinx.ext.intersphinx',
    'sphinx.ext.autodoc', 
    'sphinx.ext.autosummary',
    'sphinx.ext.viewcode', 
    'sphinx.ext.mathjax',
    'sphinx.ext.napoleon', 
    'sphinx_copybutton',
    'm2r', 
    'sphinx_rtd_theme',
    'sphinx_favicon'
]

# Automatic exclusion of prompts from the copies
copybutton_exclude = '.linenos, .gp, .go'

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ['.rst', '.md']

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'pynssp'
copyright = "2023, Gbedegnon Roseric Azondekon"
author = "Gbedegnon Roseric Azondekon"

github_user = "cdcgov"
github_repo_name = "pynssp"  # auto-detected from dirname if blank
github_version = "master"
conf_py_path = "/docs/"

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.
#
# The short X.Y version.
version = pynssp.__version__
# The full version, including alpha/beta/rc tags.
release = pynssp.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = 'en'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'default' #'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme' #'alabaster', 'book', ...https://sphinxthemes.com/
html_static_path = ["_static"]
sphinx_gallery_thumbnail_path = '_static/logo.png'

favicons = [
    {"href": "favicon/favicon.ico"},  # => use `_static/icon.svg`
    {"href": "favicon/favicon-16x16.png"},
    {"href": "favicon/favicon-32x32.png"},
    {
        "rel": "apple-touch-icon",
        "href": "favicon/apple-touch-icon.png",
    },
    {
        "rel": "android-chrome",
        "href": "favicon/android-chrome-192x192.png",
    },
    {
        "rel": "android-chrome",
        "href": "favicon/android-chrome-512x512.png",
    },
]

html_context = {
    "display_github": True,
    "github_user": github_user,
    # Auto-detect directory name.  This can break, but
    # useful as a default.
    "github_repo": github_repo_name or basename(dirname(realpath(__file__))),
    "github_version": github_version,
    "conf_py_path": conf_py_path,
}

# Theme options are theme-specific and customize the look and feel of a
# theme further.  For a list of options available for each theme, see the
# documentation.
#
html_logo = "_static/logo.png"
html_theme_options = {
    "logo": {
        "alt_text": "pynssp",
    },
    'analytics_id': 'G-5FTLT9PCW7',  #  Provided by Google in your dashboard
    'analytics_anonymize_ip': False,
    'logo_only': False,
    'display_version': True,
    'prev_next_buttons_location': 'bottom',
    'style_external_links': False,
    'vcs_pageview_mode': '',
    # 'style_nav_header_background': 'white',
    # Toc options
    'collapse_navigation': True,
    'sticky_navigation': True,
    'navigation_depth': 4,
    'includehidden': True,
    'titles_only': False
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']


# -- Options for HTMLHelp output ---------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'pynsspdoc'


# -- Options for LaTeX output ------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    'pointsize': '12pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',

    # Eliminate blank pages per http://stackoverflow.com/questions/5422997/
    'babel' : r'\usepackage[english]{babel}',
    'classoptions': ',openany,oneside',
    'fncychap': r'\usepackage[Lenny]{fncychap}',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'pynssp.tex',
     'pynssp Documentation',
     'Gbedegnon Roseric Azondekon', 'manual'),
]

latex_engine = 'pdflatex'

# -- Options for manual page output ------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'pynssp',
     'pynssp Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'pynssp',
     'pynssp Documentation',
     author,
     'pynssp',
     'A Python package for the National Syndromic Surveillance Program (NSSP) and its Community of Practice.',
     'A collection of classes and methods to advance the practice of Syndromic Surveillance.'),
]



